==> deverhood-react-1.16.51.tgz: package/src/reducers/conference.js <==
import { CONFERENCE_API } from "../actions/actionType";
import Super from "./super";
import moment from "moment";
const defaultState = {
  list: [],
  data: {},
  attended:[],
  conference:[],
  type:[]
};

export default (state = defaultState, action) => {
  let reducer = new Super(state, action);
  switch (action.type) {
    case CONFERENCE_API.SELF.ALL.SUCCESS:
      return reducer.list();
    case CONFERENCE_API.ATTENDED.ALL.SUCCESS:
      return reducer.list("attended")
    case CONFERENCE_API.CONFERENCE.ALL.SUCCESS:
      return reducer.list("conference")
    case CONFERENCE_API.TYPE.ALL.SUCCESS:
      return reducer.list("type")
    case CONFERENCE_API.SELF.GET.SUCCESS:
      return reducer.get();
    case CONFERENCE_API.SELF.POST.SUCCESS:
      return reducer.post("data");
    case CONFERENCE_API.SELF.PUT.SUCCESS:
      return reducer.put();
    case CONFERENCE_API.SELF.CLEAR.SUCCESS:
      return { ...state, list: [], data:[], conference:[],attended:[] };
    case CONFERENCE_API.DETAIL.GET.SUCCESS:
      return reducer.get();
    case CONFERENCE_API.TYPE.POST.SUCCESS:
      return reducer.post("type")
    case CONFERENCE_API.ATTENDANCE.DEL.SUCCESS:
      return {
        ...state,
        data: {
          ...state.data,
          attendances: state.data.attendances.filter(
            v => v.id.user.username !== action.data.userId
          )
        }
      };
    case CONFERENCE_API.ATTENDANCE.POST.SUCCESS:
      return {
        ...state,
        data: {
          ...state.data,
          isAttended: true
        }
      };
    case CONFERENCE_API.SELF.DEL.SUCCESS:
      return reducer.delete();
    case CONFERENCE_API.ATTENDANCE.DEL.SUCCESS:
      return {
        ...state,
        data: {
          ...state.data,
          attendances: state.data.attendances.filter(
            v => v.id.user.username !== action.data.userId
          )
        }
      };
    default:
      return state;
  }
};

==> deverhood-react-1.16.59.tgz: package/src/reducers/conference.js <==
import { CONFERENCE_API } from "../actions/actionType";
import Super from "./super";
import moment from "moment";
const defaultState = {
  list: [],
  data: {},
  attended: [],
  conference: [],
  type: [],
  upcoming: []
};

export default (state = defaultState, action) => {
  let reducer = new Super(state, action);
  switch (action.type) {
    case CONFERENCE_API.SELF.ALL.SUCCESS:
      return reducer.list();
    case CONFERENCE_API.ATTENDED.ALL.SUCCESS:
      return reducer.list("attended");
    case CONFERENCE_API.UPCOMING.ALL.SUCCESS:
      return reducer.list("upcoming");
    case CONFERENCE_API.CONFERENCE.ALL.SUCCESS:
      return reducer.list("conference");
    case CONFERENCE_API.TYPE.ALL.SUCCESS:
      return reducer.list("type");
    case CONFERENCE_API.SELF.GET.SUCCESS:
      return reducer.get();
    case CONFERENCE_API.SELF.POST.SUCCESS:
      return reducer.post("data");
    case CONFERENCE_API.SELF.PUT.SUCCESS:
      return reducer.put();
    case CONFERENCE_API.SELF.CLEAR.SUCCESS:
      return {
        ...state,
        list: [],
        data: [],
        conference: [],
        attended: [],
        upcoming: []
      };
    case CONFERENCE_API.DETAIL.GET.SUCCESS:
      return reducer.get();
    case CONFERENCE_API.TYPE.POST.SUCCESS:
      return reducer.post("type");
    case CONFERENCE_API.TYPE.PUT.SUCCESS:
      return reducer.post("type");
    case CONFERENCE_API.TYPE.DEL.SUCCESS:
      return reducer.delete();
    case CONFERENCE_API.ATTENDANCE.DEL.SUCCESS:
      return {
        ...state,
        data: {
          ...state.data,
          attendances: state.data.attendances.filter(
            v => v.id.user.username !== action.data.userId
          )
        }
      };
    case CONFERENCE_API.ATTENDANCE.POST.SUCCESS:
      return {
        ...state,
        data: {
          ...state.data,
          isAttended: true
        }
      };
    case CONFERENCE_API.SELF.DEL.SUCCESS:
      return reducer.delete();
    case CONFERENCE_API.ATTENDANCE.DEL.SUCCESS:
      return {
        ...state,
        data: {
          ...state.data,
          attendances: state.data.attendances.filter(
            v => v.id.user.username !== action.data.userId
          )
        }
      };
    default:
      return state;
  }
};
